@@ -14,5 +14,7 @@ var introspect_8c =
     [ "pw_module_info_update", "introspect_8c.html#ad82e2750dff043e644044553e7e0a348", null ],
     [ "pw_node_info_free", "introspect_8c.html#a0ee148738da978c59c3afaf91215db71", null ],
     [ "pw_node_info_update", "introspect_8c.html#a576eec63e376281ca762c48b00b7eba3", null ],
-    [ "pw_node_state_as_string", "introspect_8c.html#afb0f3403157144c358f505b1163f658a", null ]
+    [ "pw_node_state_as_string", "introspect_8c.html#afb0f3403157144c358f505b1163f658a", null ],
+    [ "pw_port_info_free", "introspect_8c.html#a6ab4af1a18861478a1a9c24f3f59ea79", null ],
+    [ "pw_port_info_update", "introspect_8c.html#adfbc0811753d8dface115a011a356360", null ]
 ];
\ No newline at end of file
