@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"resource_8h.html#a438364782ffd0444d89c747562e204f0":[9,0,46,3],
+"resource_8h.html#a5991b9355bf5bce75ef0333a28f90513":[9,0,46,13],
 "resource_8h.html#a5d4539677f164ae50e53d8b5b4bcfd79":[9,0,46,5],
 "resource_8h.html#a7c6de11938397e575506360ba3b8b922":[9,0,46,17],
 "resource_8h.html#a91805ad55d5fc0a29b40e9265edf6c09":[9,0,46,8],
@@ -104,8 +106,9 @@ var NAVTREEINDEX4 =
 "structpw__array.html#ae73d8748a287f38374152926a94d3ddc":[8,0,5,2],
 "structpw__array.html#ae8d9a82b23a44ceb033f7f6ce3b0621d":[8,0,5,1],
 "structpw__buffer.html":[8,0,6],
+"structpw__buffer.html#a925734b861209896789573f3b94a61c1":[8,0,6,1],
 "structpw__buffer.html#ad0716b5bc3f7e1cb3009c524c0192090":[8,0,6,0],
-"structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96":[8,0,6,1],
+"structpw__buffer.html#ad85549808ad885c57f85e1aee60b8c96":[8,0,6,2],
 "structpw__client__events.html":[8,0,8],
 "structpw__client__events.html#a064bb63607c0242437f6feb9bf819106":[8,0,8,4],
 "structpw__client__events.html#a0b332f68b57b4554abb19b8ccb3674cf":[8,0,8,6],
@@ -246,8 +249,5 @@ var NAVTREEINDEX4 =
 "structpw__module__info.html#a8991e7a078e6d92aa05e1922efc5bc53":[8,0,43,0],
 "structpw__module__info.html#a9a30a350e085c46a0be10df7ed9c364d":[8,0,43,5],
 "structpw__module__info.html#aae79b994769838377e2b549736f12de3":[8,0,43,1],
-"structpw__module__info.html#ae2e5f1630b990641c49fdeafb8e496b5":[8,0,43,4],
-"structpw__module__proxy__events.html":[8,0,44],
-"structpw__module__proxy__events.html#a636f903fb1c285c6df16d25483117213":[8,0,44,0],
-"structpw__module__proxy__events.html#ad8bc3f647fdde20aa4e8b695d3fb5cc9":[8,0,44,1]
+"structpw__module__info.html#ae2e5f1630b990641c49fdeafb8e496b5":[8,0,43,4]
 };
